summaryrefslogtreecommitdiffstats
path: root/cpukit/posix/src/pthread.c
diff options
context:
space:
mode:
Diffstat (limited to 'cpukit/posix/src/pthread.c')
-rw-r--r--cpukit/posix/src/pthread.c5
1 files changed, 3 insertions, 2 deletions
diff --git a/cpukit/posix/src/pthread.c b/cpukit/posix/src/pthread.c
index b46af6853b..6a980d9282 100644
--- a/cpukit/posix/src/pthread.c
+++ b/cpukit/posix/src/pthread.c
@@ -577,10 +577,11 @@ int pthread_create(
core_priority = _POSIX_Priority_To_core( attrp->schedparam.sched_priority );
/*
* Currently all POSIX threads are floating point.
*/
- is_fp = TRUE;
+ is_fp = CPU_HARDWARE_FP;
/*
* Disable dispatch for protection
@@ -577,10 +577,11 @@ int pthread_create(
core_priority = _POSIX_Priority_To_core( attrp->schedparam.sched_priority );
/*
- * Currently all POSIX threads are floating point.
+ * Currently all POSIX threads are floating point if the hardware
+ * supports it.
*/